==> sanjagh_flutter-0.0.1.tar.gz: android/src/main/java/com/sanjagh/sanjagh_flutter/MobileAd.java <==

package com.sanjagh.sanjagh_flutter;

import android.app.Activity;
import android.util.SparseArray;
import android.view.Gravity;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;

import com.sanjagh.sdk.BannerAdView;
import com.sanjagh.sdk.InterstitialAd;
import com.sanjagh.sdk.InterstitialAdListener;
import com.sanjagh.sdk.NativeExpressAdView;
import com.sanjagh.sdk.Sanjagh;

import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.MethodChannel;

abstract class MobileAd implements InterstitialAdListener {
    private static final String TAG = "flutter";
    private static SparseArray<MobileAd> allAds = new SparseArray<MobileAd>();

    final Activity activity;
    final MethodChannel channel;
    final int id;
    Status status;
    double anchorOffset;
    int anchorType;

    enum Status {
        CREATED,
        LOADING,
        FAILED,
        PENDING, // The ad will be shown when status is changed to LOADED.
        LOADED,
    }

    private MobileAd(int id, Activity activity, MethodChannel channel) {
        this.id = id;
        this.activity = activity;
        this.channel = channel;
        this.status = Status.CREATED;
        this.anchorOffset = 0.0;
        this.anchorType = Gravity.BOTTOM;
        allAds.put(id, this);
    }

    static Banner createBanner(Integer id/*, AdSize adSize*/, Activity activity, MethodChannel channel) {
        MobileAd ad = getAdForId(id);
        if (ad!=null) {
            return (Banner) ad;
        }
        else {
            return new Banner(id/*, adSize*/, activity, channel);
        }
    }

    static NativeExpress createNativeExpress(Integer id/*, AdSize adSize*/, Activity activity, MethodChannel channel) {
        MobileAd ad = getAdForId(id);
        if (ad!=null) {
            return (NativeExpress) ad;
        }
        else {
            return new NativeExpress(id/*, adSize*/, activity, channel);
        }
    }

    static Interstitial createInterstitial(Integer id, Activity activity, MethodChannel channel) {
        MobileAd ad = getAdForId(id);
        return (ad != null) ? (Interstitial) ad : new Interstitial(id, activity, channel);
    }

    static MobileAd getAdForId(Integer id) {
        return allAds.get(id);
    }

    Status getStatus() {
        return status;
    }

    abstract void load(String adUnitId, Map<String, Object> targetingInfo);

    abstract void show();

    void dispose() {
        allAds.remove(id);
    }

    private Map<String, Object> argumentsMap(Object... args) {
        System.out.println(id);
        Map<String, Object> arguments = new HashMap<String, Object>();
        arguments.put("id", id);
        for (int i = 0; i < args.length; i += 2) arguments.put(args[i].toString(), args[i + 1]);
        return arguments;
    }

    @Override
    public void onAdLoaded() {
        boolean statusWasPending = status == Status.PENDING;
        status = Status.LOADED;
        channel.invokeMethod("onAdLoaded", argumentsMap());
        /*if (statusWasPending)*/
        if (this instanceof Banner)
            show();
    }

    @Override
    public void onAdFailedToLoad() {
        channel.invokeMethod("onAdFailedToLoad", argumentsMap());
    }

    @Override
    public void onNoAd() {
        channel.invokeMethod("onNoAd", argumentsMap());

    }

    @Override
    public void onNoNetwork() {
        channel.invokeMethod("onNoNetwork", argumentsMap());

    }

    @Override
    public void onAdClosed() {
        channel.invokeMethod("onAdClosed", argumentsMap());

    }

    static class Banner extends MobileAd {
        private BannerAdView adView;

        boolean isExpandable = false;
        boolean isTransformable = true;
        int entranceType = 0;
//        private AdSize adSize;

        void setExpandableOptions(boolean isExpandable, boolean isTransformable, int entranceType){
            this.isExpandable = isExpandable;
            this.isTransformable = isTransformable;
            this.entranceType = entranceType;
        }

        private Banner(Integer id/*, AdSize adSize*/, Activity activity, MethodChannel channel) {
            super(id, activity, channel);
//            this.adSize = adSize;
        }

        @Override
        void load(String adUnitId, Map<String, Object> targetingInfo) {
            if (status != Status.CREATED) return;
            status = Status.LOADING;
            @Sanjagh.ExpandableAdEntranceTypes int entrance;
            switch (entranceType){
                case 1:
                    entrance = Sanjagh.EXPANDABLE_AD_OPTIONS_ENTRANCE_TYPE_DOWN;
                    break;
                case 2:
                    entrance = Sanjagh.EXPANDABLE_AD_OPTIONS_ENTRANCE_TYPE_UP;
                    break;
                case 3:
                    entrance = Sanjagh.EXPANDABLE_AD_OPTIONS_ENTRANCE_TYPE_FADE;
                    break;
                case 0:
                default:
                    entrance = Sanjagh.EXPANDABLE_AD_OPTIONS_ENTRANCE_TYPE_NONE;
                    break;
            }
            System.out.println(isExpandable);
            if (isExpandable){
                adView = new BannerAdView(activity, adUnitId, entrance, isTransformable);
            }else {
                adView = new BannerAdView(activity, adUnitId);
            }
            adView.setAdListener(this);

        }

        @Override
        void show() {
            if (status == Status.LOADING) {
                status = Status.PENDING;
                return;
            }
            LinearLayout content;
            if (activity.findViewById(id) == null) {
                content = new LinearLayout(activity);
                content.setId(id);
                content.setOrientation(LinearLayout.VERTICAL);
                content.setGravity(Gravity.CENTER|Gravity.BOTTOM);
                content.removeAllViews();
                content.addView(adView);
                final float scale = activity.getResources().getDisplayMetrics().density;

                if (anchorType == Gravity.BOTTOM) {
                    content.setPadding(0, 0, 0, (int) (anchorOffset * scale));
                } else {
                    content.setPadding(0, (int) (anchorOffset * scale), 0, 0);
                }
            }else {
                content = activity.findViewById(id);
                content.removeAllViews();
                content.addView(adView);
            }
            activity.addContentView(
                    content,
                    new ViewGroup.LayoutParams(
                            ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.MATCH_PARENT));
        }

        @Override
        void dispose() {
            super.dispose();

            View contentView = activity.findViewById(id);
            if (contentView == null || !(contentView.getParent() instanceof ViewGroup)) return;


            ViewGroup contentParent = (ViewGroup) (contentView.getParent());
            contentParent.removeView(contentView);
        }
    }

    static class NativeExpress extends MobileAd {
        private NativeExpressAdView adView;



        private NativeExpress(Integer id/*, AdSize adSize*/, Activity activity, MethodChannel channel) {
            super(id, activity, channel);
        }

        @Override
        void load(String adUnitId, Map<String, Object> targetingInfo) {
            if (status != Status.CREATED) return;
            status = Status.LOADING;
            adView = new NativeExpressAdView(activity,adUnitId);
            adView.setAdListener(this);

        }

        @Override
        void show() {
            if (status == Status.LOADING) {
                status = Status.PENDING;
                return;
            }
            LinearLayout content;
            if (activity.findViewById(id) == null) {
                content = new LinearLayout(activity);
                content.setId(id);
                content.setOrientation(LinearLayout.VERTICAL);
                content.setGravity(Gravity.CENTER|Gravity.BOTTOM);
                content.removeAllViews();
                content.addView(adView);
                final float scale = activity.getResources().getDisplayMetrics().density;

                if (anchorType == Gravity.BOTTOM) {
                    content.setPadding(0, 0, 0, (int) (anchorOffset * scale));
                } else {
                    content.setPadding(0, (int) (anchorOffset * scale), 0, 0);
                }
            }else {
                content = activity.findViewById(id);
                content.removeAllViews();
                content.addView(adView);
            }
            activity.addContentView(
                    content,
                    new ViewGroup.LayoutParams(
                            ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.MATCH_PARENT));
        }

        @Override
        void dispose() {
            super.dispose();

            View contentView = activity.findViewById(id);
            if (contentView == null || !(contentView.getParent() instanceof ViewGroup)) return;


            ViewGroup contentParent = (ViewGroup) (contentView.getParent());
            contentParent.removeView(contentView);
        }
    }


    static class Interstitial extends MobileAd {
        private InterstitialAd interstitial = null;

        private Interstitial(int id, Activity activity, MethodChannel channel) {
            super(id, activity, channel);
        }

        @Override
        void load(String adUnitId, Map<String, Object> targetingInfo) {
            status = Status.LOADING;

            interstitial = new InterstitialAd(activity);
            interstitial.setAdUnitId(adUnitId);

            interstitial.setAdListener(this);
            interstitial.prepareAd();
        }

        @Override
        void show() {
            if (status == Status.LOADING) {
                status = Status.PENDING;
                return;
            }
            interstitial.show(activity);
        }

    }

}

==> sanjagh_flutter-0.0.2.tar.gz: android/src/main/java/com/sanjagh/sanjagh_flutter/MobileAd.java <==

package com.sanjagh.sanjagh_flutter;

import android.app.Activity;
import android.util.SparseArray;
import android.view.Gravity;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;

import com.sanjagh.sdk.BannerAdView;
import com.sanjagh.sdk.InterstitialAd;
import com.sanjagh.sdk.InterstitialAdListener;
import com.sanjagh.sdk.NativeExpressAdView;
import com.sanjagh.sdk.Sanjagh;

import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.MethodChannel;

abstract class MobileAd implements InterstitialAdListener {
    private static final String TAG = "flutter";
    private static SparseArray<MobileAd> allAds = new SparseArray<MobileAd>();

    final Activity activity;
    final MethodChannel channel;
    final int id;
    Status status;
    double anchorOffset;
    int anchorType;

    enum Status {
        CREATED,
        LOADING,
        FAILED,
        PENDING, // The ad will be shown when status is changed to LOADED.
        LOADED,
    }

    private MobileAd(int id, Activity activity, MethodChannel channel) {
        this.id = id;
        this.activity = activity;
        this.channel = channel;
        this.status = Status.CREATED;
        this.anchorOffset = 0.0;
        this.anchorType = Gravity.BOTTOM;
        allAds.put(id, this);
    }

    static Banner createBanner(Integer id/*, AdSize adSize*/, Activity activity, MethodChannel channel) {
        MobileAd ad = getAdForId(id);
        if (ad!=null) {
            return (Banner) ad;
        }
        else {
            return new Banner(id/*, adSize*/, activity, channel);
        }
    }

    static NativeExpress createNativeExpress(Integer id/*, AdSize adSize*/, Activity activity, MethodChannel channel) {
        MobileAd ad = getAdForId(id);
        if (ad!=null) {
            return (NativeExpress) ad;
        }
        else {
            return new NativeExpress(id/*, adSize*/, activity, channel);
        }
    }

    static Interstitial createInterstitial(Integer id, Activity activity, MethodChannel channel) {
        MobileAd ad = getAdForId(id);
        return (ad != null) ? (Interstitial) ad : new Interstitial(id, activity, channel);
    }

    static MobileAd getAdForId(Integer id) {
        return allAds.get(id);
    }

    Status getStatus() {
        return status;
    }

    abstract void load(String adUnitId, Map<String, Object> targetingInfo);

    abstract void show();

    void dispose() {
        allAds.remove(id);
    }

    private Map<String, Object> argumentsMap(Object... args) {
        System.out.println(id);
        Map<String, Object> arguments = new HashMap<String, Object>();
        arguments.put("id", id);
        for (int i = 0; i < args.length; i += 2) arguments.put(args[i].toString(), args[i + 1]);
        return arguments;
    }

    @Override
    public void onAdLoaded() {
        boolean statusWasPending = status == Status.PENDING;
        status = Status.LOADED;
        channel.invokeMethod("onAdLoaded", argumentsMap());
        /*if (statusWasPending)*/
        if (this instanceof Banner)
            show();
    }

    @Override
    public void onAdFailedToLoad(int errorCode) {
        channel.invokeMethod("onAdFailedToLoad", argumentsMap());
    }

    @Override
    public void onNoAd() {
        channel.invokeMethod("onNoAd", argumentsMap());

    }

    @Override
    public void onNoNetwork() {
        channel.invokeMethod("onNoNetwork", argumentsMap());

    }

    @Override
    public void onAdClosed() {
        channel.invokeMethod("onAdClosed", argumentsMap());

    }

    static class Banner extends MobileAd {
        private BannerAdView adView;

        boolean isExpandable = false;
        boolean isTransformable = true;
        int entranceType = 0;
//        private AdSize adSize;

        void setExpandableOptions(boolean isExpandable, boolean isTransformable, int entranceType){
            this.isExpandable = isExpandable;
            this.isTransformable = isTransformable;
            this.entranceType = entranceType;
        }

        private Banner(Integer id/*, AdSize adSize*/, Activity activity, MethodChannel channel) {
            super(id, activity, channel);
//            this.adSize = adSize;
        }

        @Override
        void load(String adUnitId, Map<String, Object> targetingInfo) {
            if (status != Status.CREATED) return;
            status = Status.LOADING;
            @Sanjagh.ExpandableAdEntranceTypes int entrance;
            switch (entranceType){
                case 1:
                    entrance = Sanjagh.EXPANDABLE_AD_OPTIONS_ENTRANCE_TYPE_DOWN;
                    break;
                case 2:
                    entrance = Sanjagh.EXPANDABLE_AD_OPTIONS_ENTRANCE_TYPE_UP;
                    break;
                case 3:
                    entrance = Sanjagh.EXPANDABLE_AD_OPTIONS_ENTRANCE_TYPE_FADE;
                    break;
                case 0:
                default:
                    entrance = Sanjagh.EXPANDABLE_AD_OPTIONS_ENTRANCE_TYPE_NONE;
                    break;
            }
            System.out.println(isExpandable);
            if (isExpandable){
                adView = new BannerAdView(activity, adUnitId, entrance, isTransformable);
            }else {
                adView = new BannerAdView(activity, adUnitId);
            }
            adView.setAdListener(this);

        }

        @Override
        void show() {
            if (status == Status.LOADING) {
                status = Status.PENDING;
                return;
            }
            LinearLayout content;
            if (activity.findViewById(id) == null) {
                content = new LinearLayout(activity);
                content.setId(id);
                content.setOrientation(LinearLayout.VERTICAL);
                content.setGravity(Gravity.CENTER|Gravity.BOTTOM);
                content.removeAllViews();
                content.addView(adView);
                final float scale = activity.getResources().getDisplayMetrics().density;

                if (anchorType == Gravity.BOTTOM) {
                    content.setPadding(0, 0, 0, (int) (anchorOffset * scale));
                } else {
                    content.setPadding(0, (int) (anchorOffset * scale), 0, 0);
                }
            }else {
                content = activity.findViewById(id);
                content.removeAllViews();
                content.addView(adView);
            }
            activity.addContentView(
                    content,
                    new ViewGroup.LayoutParams(
                            ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.MATCH_PARENT));
        }

        @Override
        void dispose() {
            super.dispose();

            View contentView = activity.findViewById(id);
            if (contentView == null || !(contentView.getParent() instanceof ViewGroup)) return;


            ViewGroup contentParent = (ViewGroup) (contentView.getParent());
            contentParent.removeView(contentView);
        }
    }

    static class NativeExpress extends MobileAd {
        private NativeExpressAdView adView;



        private NativeExpress(Integer id/*, AdSize adSize*/, Activity activity, MethodChannel channel) {
            super(id, activity, channel);
        }

        @Override
        void load(String adUnitId, Map<String, Object> targetingInfo) {
            if (status != Status.CREATED) return;
            status = Status.LOADING;
            adView = new NativeExpressAdView(activity,adUnitId);
            adView.setAdListener(this);

        }

        @Override
        void show() {
            if (status == Status.LOADING) {
                status = Status.PENDING;
                return;
            }
            LinearLayout content;
            if (activity.findViewById(id) == null) {
                content = new LinearLayout(activity);
                content.setId(id);
                content.setOrientation(LinearLayout.VERTICAL);
                content.setGravity(Gravity.CENTER|Gravity.BOTTOM);
                content.removeAllViews();
                content.addView(adView);
                final float scale = activity.getResources().getDisplayMetrics().density;

                if (anchorType == Gravity.BOTTOM) {
                    content.setPadding(0, 0, 0, (int) (anchorOffset * scale));
                } else {
                    content.setPadding(0, (int) (anchorOffset * scale), 0, 0);
                }
            }else {
                content = activity.findViewById(id);
                content.removeAllViews();
                content.addView(adView);
            }
            activity.addContentView(
                    content,
                    new ViewGroup.LayoutParams(
                            ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.MATCH_PARENT));
        }

        @Override
        void dispose() {
            super.dispose();

            View contentView = activity.findViewById(id);
            if (contentView == null || !(contentView.getParent() instanceof ViewGroup)) return;


            ViewGroup contentParent = (ViewGroup) (contentView.getParent());
            contentParent.removeView(contentView);
        }
    }


    static class Interstitial extends MobileAd {
        private InterstitialAd interstitial = null;

        private Interstitial(int id, Activity activity, MethodChannel channel) {
            super(id, activity, channel);
        }

        @Override
        void load(String adUnitId, Map<String, Object> targetingInfo) {
            status = Status.LOADING;

            interstitial = new InterstitialAd(activity);
            interstitial.setAdUnitId(adUnitId);

            interstitial.setAdListener(this);
            interstitial.prepareAd();
        }

        @Override
        void show() {
            if (status == Status.LOADING) {
                status = Status.PENDING;
                return;
            }
            interstitial.show(activity);
        }

    }

}
